@@ -7,7 +7,7 @@ use Indent;
 use Toolforge::MixNMatch::Print::User;
 use Toolforge::MixNMatch::Print::YearMonth;
 
-our $VERSION = 0.01;
+our $VERSION = 0.02;
 
 sub print {
 	my ($obj, $opts_hr) = @_;
@@ -25,9 +25,11 @@ sub print {
 		$opts_hr->{'type'} ? 'Type: '.$obj->type : (),
 		$opts_hr->{'count'} ? 'Count: '.$obj->count : (),
 	);
-	my $i = Indent->new;
 
-	if ($opts_hr->{'year_months'}) {
+	my $i;
+
+	if ($opts_hr->{'year_months'} && @{$obj->year_months}) {
+		$i //= Indent->new;
 		push @print, 'Year/months:';
 		$i->add;
 		foreach my $year_month (sort { $a->year <=> $b->year || $a->month <=> $b->month }
@@ -38,7 +40,8 @@ sub print {
 		$i->remove;
 	}
 
-	if ($opts_hr->{'users'}) {
+	if ($opts_hr->{'users'} && @{$obj->users}) {
+		$i //= Indent->new;
 		push @print, 'Users:';
 		$i->add;
 		foreach my $user (reverse sort { $a->count <=> $b->count } @{$obj->users}) {
